RESOURCES_MAP = {
    # AWS resources
    'aws_acm_certificate': 'aws.security.CertificateManager',
    'aws_acmpca_certificate_authority': None,
    'aws_alb': 'aws.network.ELB',
    'aws_alb_listener': None,
    'aws_alb_target_group': None,
    'aws_ami': None,
    'aws_ami_ids': None,
    'aws_api_gateway_api_key': None,
    'aws_api_gateway_resource': 'aws.network.APIGateway',
    'aws_api_gateway_rest_api': None,
    'aws_api_gateway_vpc_link': None,
    'aws_arn': None,
    'aws_autoscaling_group': 'aws.compute.AutoScaling',
    'aws_autoscaling_groups': None,
    'aws_availability_zone': None,
    'aws_availability_zones': None,
    'aws_batch_compute_environment': None,
    'aws_batch_job_queue': None,
    'aws_billing_service_account': None,
    'aws_caller_identity': None,
    'aws_canonical_user_id': None,
    'aws_cloudformation_export': None,
    'aws_cloudformation_stack': 'aws.management.Cloudformation',
    'aws_cloudhsm_v2_cluster': None,
    'aws_cloudtrail_service_account': None,
    'aws_cloudwatch_log_group': None,
    'aws_codecommit_repository': None,
    'aws_cognito_user_pools': 'aws.security.Cognito',
    'aws_cur_report_definition': None,
    'aws_db_cluster_snapshot': None,
    'aws_db_event_categories': None,
    'aws_db_instance': 'aws.database.RDS',
    'aws_db_snapshot': None,
    'aws_dx_gateway': None,
    'aws_dynamodb_table': 'aws.database.DynamodbTable',
    'aws_ebs_snapshot': None,
    'aws_ebs_snapshot_ids': None,
    'aws_ebs_volume': None,
    'aws_ec2_transit_gateway': None,
    'aws_ec2_transit_gateway_route_table': None,
    'aws_ec2_transit_gateway_vpc_attachment': None,
    'aws_ecr_repository': 'aws.compute.EC2ContainerRegistry',
    'aws_ecs_cluster': None,
    'aws_ecs_container_definition': None,
    'aws_ecs_service': 'aws.compute.ECS',
    'aws_ecs_task_definition': None,
    'aws_efs_file_system': None,
    'aws_efs_mount_target': None,
    'aws_eip': None,
    'aws_eks_cluster': 'aws.compute.EKS',
    'aws_eks_cluster_auth': None,
    'aws_elastic_beanstalk_application': 'aws.compute.ElasticBeanstalk',
    'aws_elastic_beanstalk_hosted_zone': None,
    'aws_elastic_beanstalk_solution_stack': None,
    'aws_elasticache_cluster': 'aws.database.ElastiCache',
    'aws_elasticache_replication_group': None,
    'aws_elb': 'aws.network.ELB',
    'aws_elb_hosted_zone_id': None,
    'aws_elb_service_account': None,
    'aws_glue_script': 'aws.analytics.Glue',
    'aws_iam_account_alias': None,
    'aws_iam_group': 'aws.general.Users',
    'aws_iam_instance_profile': None,
    'aws_iam_policy': None,
    'aws_iam_policy_document': None,
    'aws_iam_role': 'aws.security.IAMRole',
    'aws_iam_server_certificate': None,
    'aws_iam_user': 'aws.general.User',
    'aws_inspector_rules_packages': None,
    'aws_instance': 'aws.compute.EC2',
    'aws_instances': None,
    'aws_internet_gateway': 'aws.network.InternetGateway',
    'aws_iot_endpoint': None,
    'aws_ip_ranges': None,
    'aws_kinesis_stream': None,
    'aws_kms_alias': 'aws.security.KMS',
    'aws_kms_ciphertext': None,
    'aws_kms_key': None,
    'aws_kms_secret': None,
    'aws_kms_secrets': None,
    'aws_lambda_function': None,
    'aws_lambda_invocation': None,
    'aws_launch_configuration': None,
    'aws_launch_template': None,
    'aws_lb': 'aws.network.ELB',
    'aws_lb_listener': None,
    'aws_lb_target_group': None,
    'aws_mq_broker': None,
    'aws_nat_gateway': 'aws.network.NATGateway',
    'aws_network_acls': 'aws.network.Nacl',
    'aws_network_interface': None,
    'aws_network_interfaces': None,
    'aws_partition': None,
    'aws_prefix_list': None,
    'aws_pricing_product': None,
    'aws_rds_cluster': 'aws.database.Aurora',
    'aws_redshift_cluster': 'aws.database.Redshift',
    'aws_redshift_service_account': None,
    'aws_region': None,
    'aws_route': 'aws.network.VPCRouter',
    'aws_route53_delegation_set': None,
    'aws_route53_zone': None,
    'aws_route_table': 'aws.network.RouteTable',
    'aws_route_tables': None,
    'aws_s3_bucket': 'aws.storage.S3',
    'aws_s3_bucket_object': None,
    'aws_secretsmanager_secret': 'aws.security.SecretsManager',
    'aws_secretsmanager_secret_version': None,
    'aws_security_group': None,
    'aws_security_groups': None,
    'aws_sns_topic': 'aws.integration.SNS',
    'aws_sqs_queue': 'aws.integration.SQS',
    'aws_ssm_document': None,
    'aws_ssm_parameter': None,
    'aws_storagegateway_local_disk': None,
    'aws_subnet': None,
    'aws_subnet_ids': None,
    'aws_vpc': 'aws.network.VPC',
    'aws_vpc_dhcp_options': None,
    'aws_vpc_endpoint': 'aws.network.Endpoint',
    'aws_vpc_endpoint_service': None,
    'aws_vpc_peering_connection': 'aws.network.VPCPeering',
    'aws_vpcs': None,
    'aws_vpn_gateway': None,
    'aws_workspaces_bundle': None,
}



# -*- coding: utf-8 -*-
import argparse
import sys
from tfdiagrams import generate


def main():
    parser = argparse.ArgumentParser()

    # graph name
    parser.add_argument('-n', default='tfdiagrams')
    # output format
    parser.add_argument('-T', default='png')
    # output file name
    parser.add_argument('-o', default='tfdiagrams.png')
    # exclude keywords separated by commas
    parser.add_argument('-e', default='')
    # input file name
    parser.add_argument('arg1', nargs='?', default='')

    args = parser.parse_args()

    if args.arg1 != '':
        # input string from file
        with open(args.arg1) as f:
            dot = f.read()
    else:
        # input string from stdin
        dot = ''
        for line in sys.stdin:
            dot += line

    # patch the file output by terraform
    dot = dot.replace('["', '[\\"').replace('"] ', '\\"] ')

    generate.Diagram(dot, args.n, args.T, args.o, args.e)
    return 0



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tfdiagrams', 'tfdiagrams.console']

package_data = \
{'': ['*'], 'tfdiagrams': ['resources/*']}

install_requires = \
['diagrams>=0.15.0,<0.16.0', 'pydot>=1.4.1,<2.0.0']

entry_points = \
{'console_scripts': ['tfdot = tfdiagrams.console:main']}

setup_kwargs = {
    'name': 'tfdiagrams',
    'version': '0.1.5',
    'description': '',
    'long_description': None,
    'author': 'Tetsuya Shinone',
    'author_email': 'info@semnil.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
